@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "frames-only-mode" "1.0.0"
+(define-package "frames-only-mode" "20241201.1533"
   "Use frames instead of Emacs windows."
-  '((emacs "24.4")
-    (seq   "2.3"))
+  '((emacs "26.3")
+    (dash  "2.13.0")
+    (s     "1.11.0"))
   :url "https://github.com/davidshepherd7/frames-only-mode"
-  :commit "5a2947d797a5d6f74d3a9c97f8c0ab6cff115b28"
-  :revdesc "5a2947d797a5"
+  :commit "9c82e779d89ead844ebd0e1a008af413e4cfc185"
+  :revdesc "9c82e779d89e"
   :keywords '("frames" "windows")
   :authors '(("David Shepherd" . "davidshepherd7@gmail.com"))
   :maintainers '(("David Shepherd" . "davidshepherd7@gmail.com")))
